@@ -1427,6 +1427,7 @@ class Socket:
         self.ws: aiohttp.ClientWebSocketResponse = ws
         self.task: Optional[asyncio.Task[None]] = None
         self.established: asyncio.Event = asyncio.Event()
+        self.connected: asyncio.Event = asyncio.Event()
         self.socket_id: Optional[str] = None
         self.activity_timeout: int = 120
         self.last_message: float = 0
@@ -1450,6 +1451,7 @@ class Socket:
             timeout=30,
         )
         self = cls(kit, ws)
+        self.connected.set()
         self.run()
         logger.debug("Socket connected")
         return self
@@ -1467,6 +1469,7 @@ class Socket:
         self.last_ping = time.perf_counter()
         self.last_pong = time.perf_counter() + 1
         try:
+            self.connected.clear()
             if self.kit.aiohttp_session is None:
                 logger.debug("Creating aiohttp session")
                 self.kit.aiohttp_session = aiohttp.ClientSession()
@@ -1478,6 +1481,8 @@ class Socket:
                 autoclose=False,
                 timeout=30,
             )
+            logger.debug("Reconnected WS %s", self.ws)
+            self.connected.set()
             for subscription in self.subscriptions:
                 subscription.succeeded.clear()
                 await self.subscribe(subscription)
@@ -1489,6 +1494,8 @@ class Socket:
     async def actual_run(self) -> None:
         while True:
             try:
+                await self.connected.wait()
+                logger.debug("Listening for messages WS %s", self.ws)
                 async for message in self.ws:
                     try:
                         # message.type is Unknown
@@ -1501,6 +1508,7 @@ class Socket:
                         event = ws_event["event"]
                         self.last_message = time.perf_counter()
                         if event == "pusher:connection_established":
+                            logger.debug("Received connection established")
                             data = self.kit.loads(ws_event["data"])
                             self.socket_id = data["socket_id"]
                             self.activity_timeout = min(
@@ -1543,7 +1551,8 @@ class Socket:
                             exc_info=e,
                         )
                 if self.ws.closed:
-                    logger.debug("actual_run -> Socket closed")
+                    self.connected.clear()
+                    logger.debug("actual_run -> Socket closed WS %s", self.ws)
                     await self.handle_socket_close()
             except asyncio.TimeoutError as e:
                 utils.print_exception_with_header("Encountered exception in socket", e)
@@ -1565,6 +1574,7 @@ class Socket:
         logger.debug("Closing and reconnecting")
         self.close_code = 1002
         with contextlib.suppress(ConnectionResetError):
+            logger.debug("Closing WS %s", self.ws)
             await self.ws.close(code=1002, message=message)
         await self.reconnect()
 
@@ -1580,7 +1590,7 @@ class Socket:
                     continue
                 if self.last_ping > self.last_pong:
                     # if pinged, not received pong, passed timeout, close and reconnect
-                    if self.last_ping + self.activity_timeout > time.perf_counter():
+                    if time.perf_counter() > self.last_ping + self.activity_timeout:
                         logger.debug("ping_pong - Pong timeout")
                         # has pinged, has not received pong, and has not received any other messages in activity_timeout
                         # therefore, connection is dead and should be closed and reconnected
@@ -1594,7 +1604,7 @@ class Socket:
                 # don't send ping if last ping was not ponged
                 if self.last_pong < self.last_ping:
                     continue
-                logger.debug("ping_pong - Sending ping")
+                logger.debug("ping_pong - Sending ping WS %s", self.ws)
                 await self.ws.send_json({"event": "pusher:ping", "data": {}})
                 self.last_ping = time.perf_counter()
             except ConnectionResetError:
@@ -1607,8 +1617,11 @@ class Socket:
 
     async def authorize_subscription(self, subscription: Subscription[Any]) -> str:
         if not self.established.is_set():
-            logger.debug("authorize_subscription - Waiting for connection to be spcket")
+            logger.debug(
+                "authorize_subscription - Waiting for connection to be established"
+            )
         await self.established.wait()
+        logger.debug("authorized_subscription - connection is established")
         if self.kit.aiohttp_session is None:
             logger.debug("authorize_subscription - Creating aiohttp session")
             self.kit.aiohttp_session = aiohttp.ClientSession()
@@ -1617,6 +1630,7 @@ class Socket:
             self.kit.subscription_auth_url,
             data={"socket_id": self.socket_id, "channel_name": subscription.channel},
         ) as response:
+            logger.debug("authorize_subscription - Got response %s", response)
             if response.status != 200:
                 raise errors.Unauthorized()
             data = await response.json()
